﻿using Microsoft.Kinect;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace KinectInteraction
{
    public class HandsTracer
    {
        public Hand RightHand {get; private set;}
        public Hand LeftHand { get; private set; }
        public event Action HandsLocationChanged;

        public HandsTracer()
        {
            RightHand = new Hand();
            LeftHand = new Hand();
        }

        public void TraceHands(object sender, SkeletonFrameReadyEventArgs e)
        {
            using (SkeletonFrame skeletonFrame = e.OpenSkeletonFrame())
            {

                if (skeletonFrame == null)
                    return;
                Skeleton[] skeletons = new Skeleton[skeletonFrame.SkeletonArrayLength];
                skeletonFrame.CopySkeletonDataTo(skeletons);
                Skeleton activeSkeleton = skeletons.FirstOrDefault(skeleton => skeleton.TrackingState == SkeletonTrackingState.Tracked);
                if (activeSkeleton == null)
                    return;
                Joint leftHand = activeSkeleton.Joints[JointType.HandLeft];
                LeftHand.SetHand(leftHand.Position, leftHand.TrackingState);
                Joint rightHand = activeSkeleton.Joints[JointType.HandRight];
                RightHand.SetHand(rightHand.Position, rightHand.TrackingState);
                if (HandsLocationChanged != null)
                    HandsLocationChanged();
            }
        }
    }
}
