﻿using Microsoft.Kinect;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace KinectInteraction
{
    public class KinectHelper
    {
        private KinectSensor sensor;
        public HandsTracer HandsTracer = new HandsTracer();
        public KinectImageHelper KinectImageHelper;


        public KinectHelper ()
	    {
            sensor = GetKinectSensor();
            if (sensor == null)
                return;
            EnableStreams();
            InitTracers();
            sensor.Start();
	    }

        private void EnableStreams()
        {
            sensor.SkeletonStream.Enable();
            sensor.ColorStream.Enable(ColorImageFormat.RgbResolution640x480Fps30);
            KinectImageHelper = new KinectImageHelper(sensor.ColorStream);
        }

        private KinectSensor GetKinectSensor()
        {
            foreach (KinectSensor optionalSensor in KinectSensor.KinectSensors)
            {
                if (optionalSensor.Status == KinectStatus.Connected)
                    return optionalSensor;
            }
            return null;
        }

        private void InitTracers()
        {
            sensor.SkeletonFrameReady += HandsTracer.TraceHands;
            this.sensor.ColorFrameReady += KinectImageHelper.SensorColorFrameReady;
        }

        public DepthImagePoint MapPointToDepthPoint(SkeletonPoint skeletonPoint, DepthImageFormat depthImageFormat)
        {
            return sensor.CoordinateMapper.MapSkeletonPointToDepthPoint(skeletonPoint, depthImageFormat);
        }
    }
}
